==> jc-1.4.0.tar.gz: polyglot/ext/jl/parse/Name.h <==
// public class polyglot.ext.jl.parse.Name

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1c6d0b1656830697 polyglot_ext_jl_parse_Name

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_ext_jl_parse_Name_H_
#define _JC_polyglot_ext_jl_parse_Name_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_ast_Expr$object;
struct _jc_polyglot_ast_NodeFactory$object;
struct _jc_polyglot_ast_PackageNode$object;
struct _jc_polyglot_ast_Prefix$object;
struct _jc_polyglot_ast_QualifierNode$object;
struct _jc_polyglot_ast_Receiver$object;
struct _jc_polyglot_ast_TypeNode$object;
struct _jc_polyglot_ext_jl_parse_Name$object;
struct _jc_polyglot_parse_BaseParser$object;
struct _jc_polyglot_types_TypeSystem$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_ext_jl_parse_Name$sub_refs	_jc_polyglot_ext_jl_parse_Name$sub_refs;
typedef struct _jc_polyglot_ext_jl_parse_Name$sub_nonrefs	_jc_polyglot_ext_jl_parse_Name$sub_nonrefs;
typedef struct _jc_polyglot_ext_jl_parse_Name$refs	_jc_polyglot_ext_jl_parse_Name$refs;
typedef struct _jc_polyglot_ext_jl_parse_Name$nonrefs	_jc_polyglot_ext_jl_parse_Name$nonrefs;
typedef struct _jc_polyglot_ext_jl_parse_Name$object	_jc_polyglot_ext_jl_parse_Name$object;

typedef const struct _jc_polyglot_ext_jl_parse_Name$vmethods	_jc_polyglot_ext_jl_parse_Name$vmethods;
typedef const struct _jc_polyglot_ext_jl_parse_Name$vtable	_jc_polyglot_ext_jl_parse_Name$vtable;
typedef const struct _jc_polyglot_ext_jl_parse_Name$vtype	_jc_polyglot_ext_jl_parse_Name$vtype;

// Constructors
extern void _jc_polyglot_ext_jl_parse_Name$method$_init$332ffbdc491c3c17(_jc_env *, struct _jc_polyglot_ext_jl_parse_Name$object *, struct _jc_polyglot_parse_BaseParser$object *, struct _jc_polyglot_util_Position$object *, struct _jc_java_lang_String$object *);
extern void _jc_polyglot_ext_jl_parse_Name$method$_init$1f743d0672f57239(_jc_env *, struct _jc_polyglot_ext_jl_parse_Name$object *, struct _jc_polyglot_parse_BaseParser$object *, struct _jc_polyglot_util_Position$object *, struct _jc_polyglot_ext_jl_parse_Name$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_object *_jc_polyglot_ext_jl_parse_Name$method$toExpr$366266d3d9ec28b2(_jc_env *, struct _jc_polyglot_ext_jl_parse_Name$object *);
extern struct _jc_object *_jc_polyglot_ext_jl_parse_Name$method$toPackage$bb62ae6bf4e53902(_jc_env *, struct _jc_polyglot_ext_jl_parse_Name$object *);
extern struct _jc_object *_jc_polyglot_ext_jl_parse_Name$method$toPrefix$8b30f5bd0b80d441(_jc_env *, struct _jc_polyglot_ext_jl_parse_Name$object *);
extern struct _jc_object *_jc_polyglot_ext_jl_parse_Name$method$toQualifier$726f62a0667665f8(_jc_env *, struct _jc_polyglot_ext_jl_parse_Name$object *);
extern struct _jc_object *_jc_polyglot_ext_jl_parse_Name$method$toReceiver$82806c7265c4c497(_jc_env *, struct _jc_polyglot_ext_jl_parse_Name$object *);
extern struct _jc_java_lang_String$object *_jc_polyglot_ext_jl_parse_Name$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_ext_jl_parse_Name$object *);
extern struct _jc_object *_jc_polyglot_ext_jl_parse_Name$method$toType$34e21a00efe1cd49(_jc_env *, struct _jc_polyglot_ext_jl_parse_Name$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_ext_jl_parse_Name$method_info$toExpr$366266d3d9ec28b2;
extern _jc_method _jc_polyglot_ext_jl_parse_Name$method_info$toPackage$bb62ae6bf4e53902;
extern _jc_method _jc_polyglot_ext_jl_parse_Name$method_info$toPrefix$8b30f5bd0b80d441;
extern _jc_method _jc_polyglot_ext_jl_parse_Name$method_info$toQualifier$726f62a0667665f8;
extern _jc_method _jc_polyglot_ext_jl_parse_Name$method_info$toReceiver$82806c7265c4c497;
extern _jc_method _jc_polyglot_ext_jl_parse_Name$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_polyglot_ext_jl_parse_Name$method_info$toType$34e21a00efe1cd49;

// Virtual methods structure
struct _jc_polyglot_ext_jl_parse_Name$vmethods {
	struct _jc_object	*(*toExpr$366266d3d9ec28b2)(_jc_env *, struct _jc_polyglot_ext_jl_parse_Name$object *);
	struct _jc_object	*(*toPackage$bb62ae6bf4e53902)(_jc_env *, struct _jc_polyglot_ext_jl_parse_Name$object *);
	struct _jc_object	*(*toPrefix$8b30f5bd0b80d441)(_jc_env *, struct _jc_polyglot_ext_jl_parse_Name$object *);
	struct _jc_object	*(*toQualifier$726f62a0667665f8)(_jc_env *, struct _jc_polyglot_ext_jl_parse_Name$object *);
	struct _jc_object	*(*toReceiver$82806c7265c4c497)(_jc_env *, struct _jc_polyglot_ext_jl_parse_Name$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_ext_jl_parse_Name$object *);
	struct _jc_object	*(*toType$34e21a00efe1cd49)(_jc_env *, struct _jc_polyglot_ext_jl_parse_Name$object *);
};

// Vtable
struct _jc_polyglot_ext_jl_parse_Name$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_ext_jl_parse_Name$vmethods	polyglot_ext_jl_parse_Name;
};

// Vtype
struct _jc_polyglot_ext_jl_parse_Name$vtype {
	_jc_type			type;
	_jc_polyglot_ext_jl_parse_Name$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_jl_parse_Name$sub_refs {
	struct _jc_polyglot_ext_jl_parse_Name$object	*prefix;
	struct _jc_java_lang_String$object	*name;
	struct _jc_polyglot_util_Position$object	*pos;
	struct _jc_object	*nf;
	struct _jc_object	*ts;
};

// Reference instance fields (object)
struct _jc_polyglot_ext_jl_parse_Name$refs {
    _jc_polyglot_ext_jl_parse_Name$sub_refs	polyglot_ext_jl_parse_Name;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_jl_parse_Name$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_jl_parse_Name$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_ext_jl_parse_Name$sub_nonrefs	polyglot_ext_jl_parse_Name;
};

// Object instance structure
struct _jc_polyglot_ext_jl_parse_Name$object {
	_jc_polyglot_ext_jl_parse_Name$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_jl_parse_Name$vtype	*vtype;
	_jc_polyglot_ext_jl_parse_Name$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_jl_parse_Name$vtype _jc_polyglot_ext_jl_parse_Name$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_jl_parse_Name, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_jl_parse_Name$class_object;

#endif	/* _JC_polyglot_ext_jl_parse_Name_H_ */

==> jc-1.4.6.tar.gz: polyglot/ext/jl/parse/Name.h <==
// public class polyglot.ext.jl.parse.Name

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1c6d0b1656830697 polyglot_ext_jl_parse_Name

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_ext_jl_parse_Name_H_
#define _JC_polyglot_ext_jl_parse_Name_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_ast_Expr$object;
struct _jc_polyglot_ast_NodeFactory$object;
struct _jc_polyglot_ast_PackageNode$object;
struct _jc_polyglot_ast_Prefix$object;
struct _jc_polyglot_ast_QualifierNode$object;
struct _jc_polyglot_ast_Receiver$object;
struct _jc_polyglot_ast_TypeNode$object;
struct _jc_polyglot_ext_jl_parse_Name$object;
struct _jc_polyglot_parse_BaseParser$object;
struct _jc_polyglot_types_TypeSystem$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_ext_jl_parse_Name$sub_refs	_jc_polyglot_ext_jl_parse_Name$sub_refs;
typedef struct _jc_polyglot_ext_jl_parse_Name$sub_nonrefs	_jc_polyglot_ext_jl_parse_Name$sub_nonrefs;
typedef struct _jc_polyglot_ext_jl_parse_Name$refs	_jc_polyglot_ext_jl_parse_Name$refs;
typedef struct _jc_polyglot_ext_jl_parse_Name$nonrefs	_jc_polyglot_ext_jl_parse_Name$nonrefs;
typedef struct _jc_polyglot_ext_jl_parse_Name$object	_jc_polyglot_ext_jl_parse_Name$object;

typedef const struct _jc_polyglot_ext_jl_parse_Name$vmethods	_jc_polyglot_ext_jl_parse_Name$vmethods;
typedef const struct _jc_polyglot_ext_jl_parse_Name$vtable	_jc_polyglot_ext_jl_parse_Name$vtable;
typedef const struct _jc_polyglot_ext_jl_parse_Name$vtype	_jc_polyglot_ext_jl_parse_Name$vtype;

// Constructors
extern void _jc_polyglot_ext_jl_parse_Name$method$_init$332ffbdc491c3c17(_jc_env *, struct _jc_polyglot_ext_jl_parse_Name$object *, struct _jc_polyglot_parse_BaseParser$object *, struct _jc_polyglot_util_Position$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_ext_jl_parse_Name$method$_init$1f743d0672f57239(_jc_env *, struct _jc_polyglot_ext_jl_parse_Name$object *, struct _jc_polyglot_parse_BaseParser$object *, struct _jc_polyglot_util_Position$object *, struct _jc_polyglot_ext_jl_parse_Name$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_polyglot_ext_jl_parse_Name$method$toExpr$366266d3d9ec28b2(_jc_env *, struct _jc_polyglot_ext_jl_parse_Name$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_ext_jl_parse_Name$method$toPackage$bb62ae6bf4e53902(_jc_env *, struct _jc_polyglot_ext_jl_parse_Name$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_ext_jl_parse_Name$method$toPrefix$8b30f5bd0b80d441(_jc_env *, struct _jc_polyglot_ext_jl_parse_Name$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_ext_jl_parse_Name$method$toQualifier$726f62a0667665f8(_jc_env *, struct _jc_polyglot_ext_jl_parse_Name$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_ext_jl_parse_Name$method$toReceiver$82806c7265c4c497(_jc_env *, struct _jc_polyglot_ext_jl_parse_Name$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_ext_jl_parse_Name$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_ext_jl_parse_Name$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_ext_jl_parse_Name$method$toType$34e21a00efe1cd49(_jc_env *, struct _jc_polyglot_ext_jl_parse_Name$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_ext_jl_parse_Name$method_info$toExpr$366266d3d9ec28b2;
extern _jc_method _jc_polyglot_ext_jl_parse_Name$method_info$toPackage$bb62ae6bf4e53902;
extern _jc_method _jc_polyglot_ext_jl_parse_Name$method_info$toPrefix$8b30f5bd0b80d441;
extern _jc_method _jc_polyglot_ext_jl_parse_Name$method_info$toQualifier$726f62a0667665f8;
extern _jc_method _jc_polyglot_ext_jl_parse_Name$method_info$toReceiver$82806c7265c4c497;
extern _jc_method _jc_polyglot_ext_jl_parse_Name$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_polyglot_ext_jl_parse_Name$method_info$toType$34e21a00efe1cd49;

// Virtual methods structure
struct _jc_polyglot_ext_jl_parse_Name$vmethods {
	struct _jc_object	*(*toExpr$366266d3d9ec28b2)(_jc_env *, struct _jc_polyglot_ext_jl_parse_Name$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*toPackage$bb62ae6bf4e53902)(_jc_env *, struct _jc_polyglot_ext_jl_parse_Name$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*toPrefix$8b30f5bd0b80d441)(_jc_env *, struct _jc_polyglot_ext_jl_parse_Name$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*toQualifier$726f62a0667665f8)(_jc_env *, struct _jc_polyglot_ext_jl_parse_Name$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*toReceiver$82806c7265c4c497)(_jc_env *, struct _jc_polyglot_ext_jl_parse_Name$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_ext_jl_parse_Name$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*toType$34e21a00efe1cd49)(_jc_env *, struct _jc_polyglot_ext_jl_parse_Name$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_ext_jl_parse_Name$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_ext_jl_parse_Name$vmethods	polyglot_ext_jl_parse_Name;
};

// Vtype
struct _jc_polyglot_ext_jl_parse_Name$vtype {
	_jc_type			type;
	_jc_polyglot_ext_jl_parse_Name$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_jl_parse_Name$sub_refs {
	struct _jc_polyglot_ext_jl_parse_Name$object	*prefix;
	struct _jc_java_lang_String$object	*name;
	struct _jc_polyglot_util_Position$object	*pos;
	struct _jc_object	*nf;
	struct _jc_object	*ts;
};

// Reference instance fields (object)
struct _jc_polyglot_ext_jl_parse_Name$refs {
    _jc_polyglot_ext_jl_parse_Name$sub_refs	polyglot_ext_jl_parse_Name;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_jl_parse_Name$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_jl_parse_Name$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_ext_jl_parse_Name$sub_nonrefs	polyglot_ext_jl_parse_Name;
};

// Object instance structure
struct _jc_polyglot_ext_jl_parse_Name$object {
	_jc_polyglot_ext_jl_parse_Name$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_jl_parse_Name$vtype	*vtype;
	_jc_polyglot_ext_jl_parse_Name$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_jl_parse_Name$vtype _jc_polyglot_ext_jl_parse_Name$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_jl_parse_Name, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_jl_parse_Name$class_object;

#endif	/* _JC_polyglot_ext_jl_parse_Name_H_ */
